@@ -5,7 +5,7 @@ docs.  In setup.py in particular, we exec this file, so it cannot import nipy
 
 # nipype version information
 # Remove .dev0 for release
-__version__ = "1.8.6"
+__version__ = "1.9.0"
 
 
 def get_nipype_gitversion():
@@ -45,7 +45,7 @@ def get_nipype_gitversion():
 if __version__.endswith("-dev"):
     gitversion = get_nipype_gitversion()
     if gitversion:
-        __version__ = "{}+{}".format(__version__, gitversion)
+        __version__ = f"{__version__}+{gitversion}"
 
 CLASSIFIERS = [
     "Development Status :: 5 - Production/Stable",
@@ -54,13 +54,13 @@ CLASSIFIERS = [
     "License :: OSI Approved :: Apache Software License",
     "Operating System :: MacOS :: MacOS X",
     "Operating System :: POSIX :: Linux",
-    "Programming Language :: Python :: 3.7",
-    "Programming Language :: Python :: 3.8",
     "Programming Language :: Python :: 3.9",
     "Programming Language :: Python :: 3.10",
+    "Programming Language :: Python :: 3.11",
+    "Programming Language :: Python :: 3.12",
     "Topic :: Scientific/Engineering",
 ]
-PYTHON_REQUIRES = ">= 3.7"
+PYTHON_REQUIRES = ">= 3.9"
 
 description = "Neuroimaging in Python: Pipelines and Interfaces"
 
@@ -102,9 +102,9 @@ existing pipeline systems.
 NIBABEL_MIN_VERSION = "2.1.0"
 NETWORKX_MIN_VERSION = "2.0"
 NUMPY_MIN_VERSION = "1.17"
+NUMPY_MAX_VERSION = "2.0"
 SCIPY_MIN_VERSION = "0.14"
 TRAITS_MIN_VERSION = "4.6"
-TRAITS_MAX_VERSION = "6.4"
 DATEUTIL_MIN_VERSION = "2.2"
 SIMPLEJSON_MIN_VERSION = "3.8.0"
 PROV_MIN_VERSION = "1.5.2"
@@ -136,7 +136,7 @@ REQUIRES = [
     "click>=%s" % CLICK_MIN_VERSION,
     "networkx>=%s" % NETWORKX_MIN_VERSION,
     "nibabel>=%s" % NIBABEL_MIN_VERSION,
-    "numpy>=%s" % NUMPY_MIN_VERSION,
+    "numpy>=%s,<%s" % (NUMPY_MIN_VERSION, NUMPY_MAX_VERSION),
     "packaging",
     "prov>=%s" % PROV_MIN_VERSION,
     "pydot>=%s" % PYDOT_MIN_VERSION,
@@ -144,15 +144,16 @@ REQUIRES = [
     "rdflib>=%s" % RDFLIB_MIN_VERSION,
     "scipy>=%s" % SCIPY_MIN_VERSION,
     "simplejson>=%s" % SIMPLEJSON_MIN_VERSION,
-    "traits>=%s,<%s,!=5.0" % (TRAITS_MIN_VERSION, TRAITS_MAX_VERSION),
+    "traits>=%s,!=5.0" % TRAITS_MIN_VERSION,
     "filelock>=3.0.0",
     "etelemetry>=0.2.0",
-    "looseversion",
+    "looseversion!=1.2",
+    "puremagic",
 ]
 
 TESTS_REQUIRES = [
     "codecov",
-    "coverage<5",
+    "coverage",
     "pytest",
     "pytest-cov",
     "pytest-env",
@@ -186,7 +187,7 @@ EXTRA_REQUIRES = {
 
 
 def _list_union(iterable):
-    return list(set(sum(iterable, [])))
+    return list(set(x for sublist in iterable for x in sublist))
 
 
 # Enable a handle to install all extra dependencies at once
