@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """
@@ -46,6 +45,7 @@ from .traits_extension import (
     InputMultiObject,
     OutputMultiPath,
     InputMultiPath,
+    Tuple,
 )
 
 from .support import Bunch, InterfaceResult, NipypeInterfaceError
