@@ -1,10 +1,8 @@
-# -*- coding: utf-8 -*-
 """ Base interfaces for dipy """
 
 import os.path as op
 import inspect
 import numpy as np
-from ... import logging
 from ..base import (
     traits,
     File,
@@ -133,11 +131,8 @@ def convert_to_traits_type(dipy_type, is_file=False):
     elif "complex" in dipy_type:
         return traits.Complex, is_mandatory
     else:
-        msg = (
-            "Error during convert_to_traits_type({0}).".format(dipy_type)
-            + "Unknown DIPY type."
-        )
-        raise IOError(msg)
+        msg = f"Error during convert_to_traits_type({dipy_type}). Unknown DIPY type."
+        raise OSError(msg)
 
 
 def create_interface_specs(class_name, params=None, BaseClass=TraitedSpec):
@@ -166,9 +161,17 @@ def create_interface_specs(class_name, params=None, BaseClass=TraitedSpec):
             traits_type, is_mandatory = convert_to_traits_type(dipy_type, is_file)
             # print(name, dipy_type, desc, is_file, traits_type, is_mandatory)
             if BaseClass.__name__ == BaseInterfaceInputSpec.__name__:
-                if len(p) > 3:
+                if len(p) > 3 and p[3] is not None:
+                    default_value = p[3]
+                    if isinstance(traits_type, traits.List) and not isinstance(
+                        default_value, list
+                    ):
+                        default_value = [default_value]
                     attr[name] = traits_type(
-                        p[3], desc=desc[-1], usedefault=True, mandatory=is_mandatory
+                        default_value,
+                        desc=desc[-1],
+                        usedefault=True,
+                        mandatory=is_mandatory,
                     )
                 else:
                     attr[name] = traits_type(desc=desc[-1], mandatory=is_mandatory)
@@ -192,7 +195,7 @@ def dipy_to_nipype_interface(cls_name, dipy_flow, BaseClass=DipyBaseInterface):
     cls_name: string
         new class name
     dipy_flow: Workflow class type.
-        It should be any children class of `dipy.workflows.workflow.Worflow`
+        It should be any children class of `dipy.workflows.workflow.Workflow`
     BaseClass: object
         nipype instance object
 
@@ -218,13 +221,13 @@ def dipy_to_nipype_interface(cls_name, dipy_flow, BaseClass=DipyBaseInterface):
     input_parameters = parser.positional_parameters + optional_params
 
     input_spec = create_interface_specs(
-        "{}InputSpec".format(cls_name),
+        f"{cls_name}InputSpec",
         input_parameters,
         BaseClass=BaseInterfaceInputSpec,
     )
 
     output_spec = create_interface_specs(
-        "{}OutputSpec".format(cls_name), output_parameters, BaseClass=TraitedSpec
+        f"{cls_name}OutputSpec", output_parameters, BaseClass=TraitedSpec
     )
 
     def _run_interface(self, runtime):
