@@ -12,8 +12,8 @@ from ..base import (
     InputMultiObject,
     TraitedSpec,
     Undefined,
-    isdefined,
     traits,
+    Tuple,
 )
 from .base import MRTrix3Base, MRTrix3BaseInputSpec
 
@@ -27,7 +27,7 @@ class DWIDenoiseInputSpec(MRTrix3BaseInputSpec):
         desc="input DWI image",
     )
     mask = File(exists=True, argstr="-mask %s", position=1, desc="mask image")
-    extent = traits.Tuple(
+    extent = Tuple(
         (traits.Int, traits.Int, traits.Int),
         argstr="-extent %d,%d,%d",
         desc="set the window size of the denoising filter. (default = 5,5,5)",
@@ -345,7 +345,7 @@ class DWIPreprocInputSpec(MRTrix3BaseInputSpec):
         argstr="-export_grad_mrtrix %s",
         desc="export new gradient files in mrtrix format",
     )
-    out_grad_fsl = traits.Tuple(
+    out_grad_fsl = Tuple(
         File("grad.bvecs", desc="bvecs"),
         File("grad.bvals", desc="bvals"),
         argstr="-export_grad_fsl %s, %s",
@@ -406,9 +406,9 @@ class DWIPreproc(MRTrix3Base):
     def _list_outputs(self):
         outputs = self.output_spec().get()
         outputs["out_file"] = op.abspath(self.inputs.out_file)
-        if self.inputs.export_grad_mrtrix:
+        if self.inputs.out_grad_mrtrix:
             outputs["out_grad_mrtrix"] = op.abspath(self.inputs.out_grad_mrtrix)
-        if self.inputs.export_grad_fsl:
+        if self.inputs.out_grad_fsl:
             outputs["out_fsl_bvec"] = op.abspath(self.inputs.out_grad_fsl[0])
             outputs["out_fsl_bval"] = op.abspath(self.inputs.out_grad_fsl[1])
 
