@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """Nilearn is a Python library for fast and easy statistical learning on NeuroImaging data."""
@@ -45,7 +44,7 @@ class SignalExtractionInputSpec(BaseInterfaceInputSpec):
         "signals.tsv",
         usedefault=True,
         exists=False,
-        desc="The name of the file to output to. " "signals.tsv by default",
+        desc="The name of the file to output to. signals.tsv by default",
     )
     incl_shared_variance = traits.Bool(
         True,
@@ -99,9 +98,7 @@ class SignalExtraction(NilearnBaseInterface, SimpleInterface):
     def _run_interface(self, runtime):
         maskers = self._process_inputs()
 
-        signals = []
-        for masker in maskers:
-            signals.append(masker.fit_transform(self.inputs.in_file))
+        signals = [masker.fit_transform(self.inputs.in_file) for masker in maskers]
         region_signals = np.hstack(signals)
 
         output = np.vstack((self.inputs.class_labels, region_signals.astype(str)))
@@ -128,10 +125,10 @@ class SignalExtraction(NilearnBaseInterface, SimpleInterface):
         else:  # 4d labels
             n_labels = label_data.shape[3]
             if self.inputs.incl_shared_variance:  # independent computation
-                for img in nli.iter_img(label_data):
-                    maskers.append(
-                        nl.NiftiMapsMasker(self._4d(img.dataobj, img.affine))
-                    )
+                maskers.extend(
+                    nl.NiftiMapsMasker(self._4d(img.dataobj, img.affine))
+                    for img in nli.iter_img(label_data)
+                )
             else:  # one computation fitting all
                 maskers.append(nl.NiftiMapsMasker(label_data))
 
@@ -155,7 +152,7 @@ class SignalExtraction(NilearnBaseInterface, SimpleInterface):
         if self.inputs.include_global:
             global_label_data = label_data.dataobj.sum(axis=3)  # sum across all regions
             global_label_data = (
-                np.rint(global_label_data).astype(int).clip(0, 1)
+                np.rint(global_label_data).clip(0, 1).astype('u1')
             )  # binarize
             global_label_data = self._4d(global_label_data, label_data.affine)
             global_masker = nl.NiftiLabelsMasker(
