@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """Tests for the engine module
@@ -26,7 +25,7 @@ from .test_base import EngineTestInterface
 def test_1mod(iterables, expected):
     pipe = pe.Workflow(name="pipe")
     mod1 = pe.Node(interface=EngineTestInterface(), name="mod1")
-    setattr(mod1, "iterables", iterables["1"])
+    mod1.iterables = iterables["1"]
     pipe.add_nodes([mod1])
     pipe._flatgraph = pipe._create_flat_graph()
     pipe._execgraph = pe.generate_expanded_graph(deepcopy(pipe._flatgraph))
@@ -50,7 +49,7 @@ def test_2mods(iterables, expected):
     mod1 = pe.Node(interface=EngineTestInterface(), name="mod1")
     mod2 = pe.Node(interface=EngineTestInterface(), name="mod2")
     for nr in ["1", "2"]:
-        setattr(eval("mod" + nr), "iterables", iterables[nr])
+        eval("mod" + nr).iterables = iterables[nr]
     pipe.connect([(mod1, mod2, [("output1", "input2")])])
     pipe._flatgraph = pipe._create_flat_graph()
     pipe._execgraph = pe.generate_expanded_graph(deepcopy(pipe._flatgraph))
@@ -88,7 +87,7 @@ def test_3mods(iterables, expected, connect):
     mod2 = pe.Node(interface=EngineTestInterface(), name="mod2")
     mod3 = pe.Node(interface=EngineTestInterface(), name="mod3")
     for nr in ["1", "2", "3"]:
-        setattr(eval("mod" + nr), "iterables", iterables[nr])
+        eval("mod" + nr).iterables = iterables[nr]
     if connect == ("1-2", "2-3"):
         pipe.connect(
             [
@@ -196,7 +195,6 @@ def test_synchronize_tuples_expansion():
 
 
 def test_itersource_expansion():
-
     wf1 = pe.Workflow(name="test")
     node1 = pe.Node(EngineTestInterface(), name="node1")
     node1.iterables = ("input1", [1, 2])
@@ -356,9 +354,9 @@ def test_mapnode_json(tmpdir):
     assert len(outjson) == 1
 
     # check that multiple json's don't trigger rerun
-    with open(os.path.join(node.output_dir(), "test.json"), "wt") as fp:
+    with open(os.path.join(node.output_dir(), "test.json"), "w") as fp:
         fp.write("dummy file")
-    w1.config["execution"].update(**{"stop_on_first_rerun": True})
+    w1.config["execution"].update(stop_on_first_rerun=True)
 
     w1.run()
 
@@ -459,7 +457,7 @@ def test_deep_nested_write_graph_runs(tmpdir):
             pipe = pe.Workflow(name="pipe")
             parent = pipe
             for depth in range(10):
-                sub = pe.Workflow(name="pipe_nest_{}".format(depth))
+                sub = pe.Workflow(name=f"pipe_nest_{depth}")
                 parent.add_nodes([sub])
                 parent = sub
             mod1 = pe.Node(interface=EngineTestInterface(), name="mod1")
@@ -482,14 +480,9 @@ def test_deep_nested_write_graph_runs(tmpdir):
                 pass
 
 
-import networkx
-
-# Format of the graph has slightly changed
-graph_str = '""' if int(networkx.__version__.split(".")[0]) == 1 else ""
-
 # examples of dot files used in the following test
 dotfile_orig = [
-    "strict digraph " + graph_str + " {\n",
+    "strict digraph {\n",
     '"mod1 (engine)";\n',
     '"mod2 (engine)";\n',
     '"mod1 (engine)" -> "mod2 (engine)";\n',
